@@ -1509,7 +1509,7 @@ def test_patch_series_error(mocker, tuxsuite_config):
     assert "Error: Invalid value for '-p' / '--patch-series'" in result.output
 
 
-def test_patch_series_pass(mocker, sample_patch_tgz, tuxsuite_config):
+def test_patch_series_pass(mocker, sample_patch_tgz, sample_patch_mbx, tuxsuite_config):
     build = mocker.patch("tuxsuite.Build.build")
     wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
     runner = CliRunner()
