@@ -6,8 +6,12 @@ import hashlib
 import json
 import mimetypes
 import os
+import pathlib
 import random
 import re
+import sys
+import shutil
+import subprocess
 import tarfile
 import time
 import tuxsuite.exceptions
@@ -57,11 +61,29 @@ def handle_patch(patch_path):
     patch_is_web_url = False
     patch_content = None
     patch_file = os.path.basename(patch_path)
+    if "lore.kernel.org" in patch_path:
+        if shutil.which("b4"):
+            patch_file = f"/tmp/{uuid.uuid4().hex}.mbx"
+            subprocess.check_output(["b4", "am", "-n", patch_file, patch_path])
+            patch_path = patch_file
+            patch_file = os.path.basename(patch_file)
+        else:
+            print(
+                f"\033[91mERROR: 'b4' not found to download patch from {patch_path}\033[0m"
+            )
+            sys.exit(1)
     if urlparse(patch_path).scheme in ["http", "https"]:
         patch_file = patch_path
         patch_content = b""
         patch_is_web_url = True
     elif os.path.isfile(patch_path):
+        # Rename .mbx to .mbox on the fly.
+        if pathlib.Path(patch_path).suffix == ".mbx":
+            new_patch_path = os.path.join(
+                os.path.dirname(patch_path), pathlib.Path(patch_path).stem + ".mbox"
+            )
+            os.rename(os.path.abspath(patch_path), new_patch_path)
+            patch_path = new_patch_path
         file_type, file_encoding = mimetypes.guess_type(patch_path)
         if file_type in [
             "application/mbox",
@@ -963,11 +985,11 @@ class Bitbake(HeadersMixin):
 
     @attrs(kw_only=True, order=False)
     class BuildDefinition:
-        target = attrib()
-        envsetup = attrib()
-        distro = attrib()
-        machine = attrib()
-        sources = attrib(default={})
+        target = attrib(default=None)
+        envsetup = attrib(default=None)
+        distro = attrib(default=None)
+        machine = attrib(default=None)
+        sources = attrib()
         artifacts = attrib(default=[])
         environment = attrib(default={})
         local_conf = attrib(default=[])
