@@ -8,7 +8,9 @@ import logging
 import re
 import uuid
 import yaml
+
 from tuxsuite import requests
+import tuxsuite.schema
 
 
 def getenv(name, default=None):
@@ -279,6 +281,7 @@ class PlanConfig:
         self.filename = filename
         self.job_name = job_name
         self.plan = []
+        self.schema_warning = ""
         self.__load_config__()
 
     def __load_config__(self):
@@ -291,6 +294,11 @@ class PlanConfig:
         except (FileNotFoundError, yaml.loader.ParserError) as e:
             raise InvalidConfiguration(str(e))
 
+        try:
+            tuxsuite.schema.plan()(config)
+        except Exception as exc:
+            self.schema_warning = str(exc)
+
         if not isinstance(config, dict):
             raise InvalidConfiguration(
                 f"Plan configuration in {self.filename} is invalid"
